//
//  Sample.m

#import "Sample.h"
#import "Constants.h"

enum {
	MKLimitNone = 0,
	MKLimitTitle,
	MKLimitIMDb
};

@implementation Sample


- (NSString *)countryCode {
	return @"US";
}

- (NSString *)languageCode {
	return @"en";
}

/*
 
 // Limit a search to certain values
 - (NSArray *)limits {
 return [NSArray arrayWithObjects:@"none", @"title", nil];
 }
 
 // Different search groups
 - (NSArray *)types {
    return nil;
 }
 
 // Different sorting options
 - (NSArray *)sorts {
 return [NSArray arrayWithObjects:@"Relevance", @"Title", nil];
 }
 */


- (void)searchForString:(NSString *)aString limit:(NSInteger)aLimitNumber type:(NSInteger)typeNumber sort:(NSInteger)sortNumber sender:(id)sender { 	
	
	self.delegate = sender;
	[resultsTitles removeAllObjects];
	[resultsURLs  removeAllObjects];
	
	if (aLimitNumber == MKLimitIMDb) {
		[resultsURLs  addObject:aString];
		[resultsTitles addObject:[NSString stringWithFormat:@"IMDB #:%@", aString]];
		[delegate searchReturnedNumberOfResults:1 sender:self];	
		return;
	}
	
	NSMutableString *searchString = [NSMutableString stringWithString:aString];
	[searchString replaceOccurrencesOfString:@" " withString:@"+" options:NSLiteralSearch range:NSMakeRange(0, [searchString length])];
	NSString *encodedString = [searchString stringByAddingPercentEncodingWithAllowedCharacters:[NSCharacterSet URLQueryAllowedCharacterSet]];
    NSString *searchURL = [NSString stringWithFormat:@"http://www.awebiste.com/search?keyword=%@", encodedString];
    NSLog(@"A sample search URL: %@", searchURL);
	
	// Here we added a function to hide the complexity of URL downloading. It calls downloadComplete: with the final download
	//[self downloadWebPage:searchURL];
	[self downloadWebPage:@"http://www.bruji.com/dvdpedia"]; //A static URL for the sample
	
	// A post example
	//NSString *postBody = [@"type=1&search=" stringByAppendingString:encodedString];
	//[self downloadWebPage:@"http://www.bruji.com/post.php?" withPost:postBody encoding:NSISOLatin1StringEncoding];
	
}


// Get more info command
- (void)searchFor:(NSDictionary *)searchDict sender:(id)sender {
	
	if ([searchDict objectForKey:@"keyword"]) { //Backward compatability
		NSString *searchTerm = [searchDict objectForKey:@"keyword"];
        [self searchForString:searchTerm limit:0 type:0 sort:0 sender:sender];
	}
	else if ([searchDict objectForKey:@"imdb"]) {
		[self searchForString:[searchDict objectForKey:@"imdb"] limit:MKLimitIMDb type:0 sort:0 sender:sender];
	}
	else if ([searchDict objectForKey:@"url"] 
			 && [[searchDict objectForKey:@"url"] rangeOfString:@"imdb.com/title/tt"].location != NSNotFound) 	{
        NSString *imdbNumber = [searchDict objectForKey:@"url"];
        NSRange aRange = [imdbNumber rangeOfString:@"imdb.com/title/tt"];
        if ([imdbNumber length] >= aRange.location + aRange.length + 7) { //Check that the URL is long enough
            imdbNumber = [imdbNumber substringWithRange:NSMakeRange(aRange.location + aRange.length, 7)];
            [self searchForString:imdbNumber limit:MKLimitIMDb type:0 sort:0 sender:sender];
        }
	}    
	else if ([searchDict objectForKey:@"title"] != nil) {
		NSString *searchTerm = [searchDict objectForKey:@"title"];
        [self searchForString:searchTerm limit:0 type:0 sort:0 sender:sender];
	}
	else {
		[sender searchReturnedNumberOfResults:0 sender:self];
	}
}


- (void)downloadComplete:(NSString *)HTMLSource {
	
	// Search the page and create a list of result titles and URLs for the details information
	// In this sample we pick all the links that start with "http"
    
    NSArray *resultsSection = [HTMLSource stringsBetween:@"<a " and:@"</a>"];
	for (NSString *nextMovie in resultsSection) {
		NSString *url = [nextMovie stringBetween:@"href=\"" and:@"\""];
		NSString *title = [[nextMovie stringBetween:@">" and:@"<"] stringByCleaningHTML];
		
		if (url && title) {
			[resultsTitles addObject:title];
			[resultsURLs addObject:url];
		}
	}
    
    [delegate searchReturnedNumberOfResults:[resultsURLs count] sender:self];
}


- (NSDictionary *)resultNumber:(int)number {
	//Get the details for one of the results and return it as a dictionary
	
	NSMutableDictionary *resultsDict = [NSMutableDictionary dictionary];
	
	if (number >= [resultsURLs count]) {
		NSLog(@"Error: sample requested out of range: %d of %lu", number, (unsigned long)[resultsURLs count]);
		[resultsDict setObject:@"No data found on sample" forKey:@"title"];
		return resultsDict;	
	}
	
	//This would be the real url to use, the one requested from the stored in resultsURLs; But changed for a static one as an example
	//NSString *detailsURL = [resultsURLs objectAtIndex:number];
	NSString *detailsURL = @"http://www.bruji.com/dvdpedia";
	
	NSURLRequest *theRequest = [NSURLRequest requestWithURL:[NSURL URLWithString:detailsURL] cachePolicy:NSURLRequestUseProtocolCachePolicy timeoutInterval:15.0];
	
    NSData *dataReceived = [NSURLSession sendSynchronousRequest:theRequest returningResponse:NULL error:NULL];
    NSString *results = [[[NSString alloc] initWithData:dataReceived encoding:NSUTF8StringEncoding] autorelease];

	
	if (results == nil)
		return nil;
	
	//NSLog(@"%@", detailsURL);
     [resultsDict setObject:detailsURL forKey:@"url"];
     [resultsDict setValue:[self countryCode] forKey:@"locale"];
     [resultsDict setValue:[self languageCode] forKey:@"localeLanguage"];

	
	NSString *title = [resultsTitles objectAtIndex:number];
	if (title)
		[resultsDict setObject:title forKey:@"title"];
	
	//From the dvdpedia page we pick up the version number and enter it for director
	NSString *version = [results stringBetween:@"Version: " and:@"("];
	if (version)
		[resultsDict setObject:version forKey:MKKeyDVDDirector];
	
	
	//and the icon image for good measure
	NSString *imageURL = [results stringBetween:@"class=\"bigScreenshot" and:@"/>"];
	imageURL = [imageURL stringBetween:@"src=\"" and:@"\""];
	if (imageURL) {
		imageURL = [NSString stringWithFormat:@"http://www.bruji.com/dvdpedia/%@", imageURL];
		[resultsDict setObject:imageURL forKey:MKKeyEntryImageLocation];
	}
	
     return resultsDict;
}

/* 
#pragma mark -
#pragma mark Menu Command

- (id)init {
    self = [super init];
    if (self) {
		NSMenuItem *aMenuItem = [[[NSMenuItem alloc] init] autorelease];
		[aMenuItem setTitle:@"A Test Menu"];
		[aMenuItem setTarget:self];
		[aMenuItem setAction:@selector(doTest:)];
		
		NSMenuItem *secondMenuItem = [[[NSMenuItem alloc] init] autorelease];
		[secondMenuItem setTitle:@"A Second Menu"];
		[secondMenuItem setTarget:self];
		[secondMenuItem setAction:@selector(doSecondTest:)];

		
		 MyPluginManager *pluginManager = [[NSApp delegate] pluginManager];
		[pluginManager addMenuItem:aMenuItem];
		[pluginManager addMenuItem:secondMenuItem];
		[pluginManager addMenuItem:[NSMenuItem separatorItem]];				
	}
	return self;
}

 
- (IBAction)doTest:(id)sender {
	NSLog(@"Doing a Test");
}
 
 
- (IBAction)doSecondTest:(id)sender {
	NSLog(@"Doing another Test");
}
 */

@end
